@@ -31,21 +31,22 @@ from elixir.fields import has_field, with_fields, Field
 from elixir.relationships import belongs_to, has_one, has_many, \
                                  has_and_belongs_to_many, \
                                  ManyToOne, OneToOne, OneToMany, ManyToMany
-from elixir.properties import has_property, GenericProperty, ColumnProperty
+from elixir.properties import has_property, GenericProperty, ColumnProperty, \
+                              Synonym
 from elixir.statements import Statement
 
 
-__version__ = '0.5.0'
+__version__ = '0.5.2'
 
 __all__ = ['Entity', 'EntityMeta',
-           'Field', 'has_field', 'with_fields',
-           'has_property', 'GenericProperty', 'ColumnProperty',
+           'Field', 'has_field', 'with_fields', 
+           'has_property', 'GenericProperty', 'ColumnProperty', 'Synonym',
            'belongs_to', 'has_one', 'has_many', 'has_and_belongs_to_many',
            'ManyToOne', 'OneToOne', 'OneToMany', 'ManyToMany',
            'using_options', 'using_table_options', 'using_mapper_options',
            'options_defaults', 'metadata', 'objectstore', 'session',
            'create_all', 'drop_all',
-           'setup_all', 'cleanup_all', 
+           'setup_all', 'cleanup_all',
            'setup_entities', 'cleanup_entities'] + \
            sqlalchemy.types.__all__
 
